@@ -7,9 +7,9 @@ copyright: authors
 #======================================================================
 __version__ = "$Revision: 1.36 $"
 __author__ = "R.Terry, S.J.Tan, K.Hilbert"
-__license__ = "GPL (details at http://www.gnu.org)"
+__license__ = "GPL v2 or later (details at http://www.gnu.org)"
 
-import sys, time, logging, webbrowser
+import sys, time, logging
 
 
 import wx
@@ -18,7 +18,7 @@ import wx
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
 from Gnumed.pycommon import gmDispatcher, gmMatchProvider, gmTools, gmI18N
-from Gnumed.pycommon import gmCfg, gmDateTime
+from Gnumed.pycommon import gmCfg, gmDateTime, gmNetworkTools
 from Gnumed.business import gmPerson, gmVaccination, gmSurgery
 from Gnumed.wxpython import gmPhraseWheel, gmTerryGuiParts, gmRegetMixin, gmGuiHelpers
 from Gnumed.wxpython import gmEditArea, gmListWidgets
@@ -126,7 +126,10 @@ class cVaccinationIndicationsPnl(wxgVaccinationIndicationsPnl.wxgVaccinationIndi
 	#------------------------------------------------------------------
 	def select(self, indications=None):
 		for indication in indications:
-			self.__indication2field[indication].SetValue(True)
+			try:
+				self.__indication2field[indication].SetValue(True)
+			except KeyError:
+				pass
 	#------------------------------------------------------------------
 	def _get_selected_indications(self):
 		indications = []
@@ -204,8 +207,8 @@ def manage_vaccines(parent=None):
 				)
 			),
 			v['preparation'],
-			u'%s (%s)' % (v['route_abbreviation'], v['route_description']),
-			gmTools.bool2subst(v['is_live'], gmTools.u_checkmark_thin, u''),
+			#u'%s (%s)' % (v['route_abbreviation'], v['route_description']),
+			#gmTools.bool2subst(v['is_live'], gmTools.u_checkmark_thin, u'', u'?'),
 			gmTools.coalesce(v['atc_code'], u''),
 			u'%s%s' % (
 				gmTools.coalesce(v['min_age'], u'?'),
@@ -220,7 +223,8 @@ def manage_vaccines(parent=None):
 		parent = parent,
 		msg = _('\nThe vaccines currently known to GNUmed.\n'),
 		caption = _('Showing vaccines.'),
-		columns = [ u'#', _('Brand'), _('Preparation'), _(u'Route'), _('Live'), _('ATC'), _('Age range'), _('Comment') ],
+		#columns = [ u'#', _('Brand'), _('Preparation'), _(u'Route'), _('Live'), _('ATC'), _('Age range'), _('Comment') ],
+		columns = [ u'#', _('Brand'), _('Preparation'), _('ATC'), _('Age range'), _('Comment') ],
 		single_selection = True,
 		refresh_callback = refresh,
 		edit_callback = edit,
@@ -242,16 +246,20 @@ class cBatchNoPhraseWheel(gmPhraseWheel.cPhraseWheel):
 		}
 
 		query = u"""
-SELECT code, batch_no FROM (
+SELECT data, field_label, list_label FROM (
 
-	SELECT distinct on (batch_no) code, batch_no, rank FROM (
-
-		(
+	SELECT distinct on (field_label)
+		data,
+		field_label,
+		list_label,
+		rank
+	FROM ((
 			-- batch_no by vaccine
 			SELECT
-				batch_no AS code,
-				batch_no,
-				1 AS rank
+				batch_no AS data,
+				batch_no AS field_label,
+				batch_no || ' (' || vaccine || ')' AS list_label,
+				1 as rank
 			FROM
 				clin.v_pat_vaccinations
 			WHERE
@@ -260,8 +268,9 @@ SELECT code, batch_no FROM (
 		) UNION ALL (
 			-- batch_no for any vaccine
 			SELECT
-				batch_no AS code,
-				batch_no,
+				batch_no AS data,
+				batch_no AS field_label,
+				batch_no || ' (' || vaccine || ')' AS list_label,
 				2 AS rank
 			FROM
 				clin.v_pat_vaccinations
@@ -273,7 +282,7 @@ SELECT code, batch_no FROM (
 
 ) as unique_matches
 
-ORDER BY rank, batch_no
+ORDER BY rank, list_label
 LIMIT 25
 """
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries = query, context = context)
@@ -292,16 +301,18 @@ class cVaccinePhraseWheel(gmPhraseWheel.cPhraseWheel):
 
 		# consider ATCs in ref.branded_drug and vacc_indication
 		query = u"""
-SELECT pk_vaccine, description FROM (
+SELECT data, list_label, field_label FROM (
 
-	SELECT DISTINCT ON (pk_vaccine) pk_vaccine, description FROM (
-
-		(
+	SELECT DISTINCT ON (data)
+		data,
+		list_label,
+		field_label
+	FROM ((
 			-- fragment -> vaccine
 			SELECT
-				pk_vaccine,
-				vaccine || ' (' || array_to_string(l10n_indications, ', ') || ')'
-					AS description
+				pk_vaccine AS data,
+				vaccine || ' (' || array_to_string(l10n_indications, ', ') || ')' AS list_label,
+				vaccine AS field_label
 			FROM
 				clin.v_vaccines
 			WHERE
@@ -311,9 +322,9 @@ SELECT pk_vaccine, description FROM (
 
 			-- fragment -> localized indication -> vaccines
 			SELECT
-				pk_vaccine,
-				vaccine || ' (' || array_to_string(l10n_indications, ', ') || ')'
-					AS description
+				pk_vaccine AS data,
+				vaccine || ' (' || array_to_string(l10n_indications, ', ') || ')' AS list_label,
+				vaccine AS field_label
 			FROM
 				clin.v_indications4vaccine
 			WHERE
@@ -323,9 +334,9 @@ SELECT pk_vaccine, description FROM (
 
 			-- fragment -> indication -> vaccines
 			SELECT
-				pk_vaccine,
-				vaccine || ' (' || array_to_string(indications, ', ') || ')'
-					AS description
+				pk_vaccine AS data,
+				vaccine || ' (' || array_to_string(indications, ', ') || ')' AS list_label,
+				vaccine AS field_label
 			FROM
 				clin.v_indications4vaccine
 			WHERE
@@ -335,7 +346,7 @@ SELECT pk_vaccine, description FROM (
 
 ) AS total
 
-ORDER by description
+ORDER by list_label
 LIMIT 25
 """
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries = query)
@@ -345,7 +356,7 @@ LIMIT 25
 		self.selection_only = True
 	#------------------------------------------------------------------
 	def _data2instance(self):
-		return gmVaccination.cVaccine(aPK_obj = self.data)
+		return gmVaccination.cVaccine(aPK_obj = self.GetData())
 #----------------------------------------------------------------------
 from Gnumed.wxGladeWidgets import wxgVaccineEAPnl
 
@@ -371,24 +382,24 @@ class cVaccineEAPnl(wxgVaccineEAPnl.wxgVaccineEAPnl, gmEditArea.cGenericEditArea
 	#----------------------------------------------------------------
 	def __init_ui(self):
 
-		# route
-		query = u"""
-			SELECT DISTINCT ON (abbreviation)
-				id,
-				abbreviation || ' (' || _(description) || ')'
-			FROM
-				clin.vacc_route
-			WHERE
-				abbreviation %(fragment_condition)s
-					OR
-				description %(fragment_condition)s
-			ORDER BY
-				abbreviation
-		"""
-		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query)
-		mp.setThresholds(1, 2, 3)
-		self._PRW_route.matcher = mp
-		self._PRW_route.selection_only = True
+#		# route
+#		query = u"""
+#			SELECT DISTINCT ON (abbreviation)
+#				id,
+#				abbreviation || ' (' || _(description) || ')'
+#			FROM
+#				clin.vacc_route
+#			WHERE
+#				abbreviation %(fragment_condition)s
+#					OR
+#				description %(fragment_condition)s
+#			ORDER BY
+#				abbreviation
+#		"""
+#		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query)
+#		mp.setThresholds(1, 2, 3)
+#		self._PRW_route.matcher = mp
+#		self._PRW_route.selection_only = True
 
 		#self._PRW_age_min = gmPhraseWheel.cPhraseWheel(self, -1, "", style=wx.NO_BORDER)
 		#self._PRW_age_max = gmPhraseWheel.cPhraseWheel(self, -1, "", style=wx.NO_BORDER)
@@ -408,11 +419,11 @@ class cVaccineEAPnl(wxgVaccineEAPnl.wxgVaccineEAPnl, gmEditArea.cGenericEditArea
 		else:
 			self._PRW_brand.display_as_valid(True)
 
-		if self._PRW_route.GetData() is None:
-			has_errors = True
-			self._PRW_route.display_as_valid(False)
-		else:
-			self._PRW_route.display_as_valid(True)
+#		if self._PRW_route.GetData() is None:
+#			has_errors = True
+#			self._PRW_route.display_as_valid(False)
+#		else:
+#			self._PRW_route.display_as_valid(True)
 
 		if not self._PNL_indications.has_selection:
 			has_errors = True
@@ -492,8 +503,8 @@ class cVaccineEAPnl(wxgVaccineEAPnl.wxgVaccineEAPnl, gmEditArea.cGenericEditArea
 			indications = self._PNL_indications.selected_indications
 		)
 
-		data['pk_route'] = self._PRW_route.GetData()
-		data['is_live'] = self._CHBOX_live.GetValue()
+#		data['pk_route'] = self._PRW_route.GetData()
+#		data['is_live'] = self._CHBOX_live.GetValue()
 		val = self._PRW_age_min.GetValue().strip()
 		if val != u'':
 			data['min_age'] = gmDateTime.str2interval(val)
@@ -507,11 +518,11 @@ class cVaccineEAPnl(wxgVaccineEAPnl.wxgVaccineEAPnl, gmEditArea.cGenericEditArea
 		data.save()
 
 		drug = data.brand
-		drug['is_fake'] = self._CHBOX_fake.GetValue()
+		drug['is_fake_brand'] = self._CHBOX_fake.GetValue()
 		val = self._PRW_atc.GetData()
 		if val is not None:
 			if val != u'J07':
-				drug['atc_code'] = val.strip()
+				drug['atc'] = val.strip()
 		drug.save()
 
 		# must be done very late or else the property access
@@ -524,19 +535,19 @@ class cVaccineEAPnl(wxgVaccineEAPnl.wxgVaccineEAPnl, gmEditArea.cGenericEditArea
 	def _save_as_update(self):
 
 		drug = self.data.brand
-		drug['description'] = self._PRW_brand.GetValue().strip()
-		drug['is_fake'] = self._CHBOX_fake.GetValue()
+		drug['brand'] = self._PRW_brand.GetValue().strip()
+		drug['is_fake_brand'] = self._CHBOX_fake.GetValue()
 		val = self._PRW_atc.GetData()
 		if val is not None:
 			if val != u'J07':
-				drug['atc_code'] = val.strip()
+				drug['atc'] = val.strip()
 		drug.save()
 
 		# the validator already asked for changes so just do it
 		self.data.set_indications(indications = self._PNL_indications.selected_indications)
 
-		self.data['pk_route'] = self._PRW_route.GetData()
-		self.data['is_live'] = self._CHBOX_live.GetValue()
+#		self.data['pk_route'] = self._PRW_route.GetData()
+#		self.data['is_live'] = self._CHBOX_live.GetValue()
 		val = self._PRW_age_min.GetValue().strip()
 		if val != u'':
 			self.data['min_age'] = gmDateTime.str2interval(val)
@@ -551,8 +562,8 @@ class cVaccineEAPnl(wxgVaccineEAPnl.wxgVaccineEAPnl, gmEditArea.cGenericEditArea
 	#----------------------------------------------------------------
 	def _refresh_as_new(self):
 		self._PRW_brand.SetText(value = u'', data = None, suppress_smarts = True)
-		self._PRW_route.SetText(value = u'intramuscular')
-		self._CHBOX_live.SetValue(False)
+#		self._PRW_route.SetText(value = u'intramuscular')
+#		self._CHBOX_live.SetValue(True)
 		self._CHBOX_fake.SetValue(False)
 		self._PNL_indications.clear_all()
 		self._PRW_atc.SetText(value = u'', data = None, suppress_smarts = True)
@@ -564,8 +575,8 @@ class cVaccineEAPnl(wxgVaccineEAPnl.wxgVaccineEAPnl, gmEditArea.cGenericEditArea
 	#----------------------------------------------------------------
 	def _refresh_from_existing(self):
 		self._PRW_brand.SetText(value = self.data['vaccine'], data = self.data['pk_brand'])
-		self._PRW_route.SetText(value = self.data['route_description'], data = self.data['pk_route'])
-		self._CHBOX_live.SetValue(self.data['is_live'])
+#		self._PRW_route.SetText(value = self.data['route_description'], data = self.data['pk_route'])
+#		self._CHBOX_live.SetValue(self.data['is_live'])
 		self._CHBOX_fake.SetValue(self.data['is_fake_vaccine'])
 		self._PNL_indications.select(self.data['indications'])
 		self._PRW_atc.SetText(value = self.data['atc_code'], data = self.data['atc_code'])
@@ -623,11 +634,7 @@ def manage_vaccinations(parent=None):
 			default = u'http://www.bundesaerztekammer.de/downloads/ImpfempfehlungenRKI2009.pdf'
 		)
 
-		webbrowser.open (
-			url = url,
-			new = False,
-			autoraise = True
-		)
+		gmNetworkTools.open_url_in_browser(url = url)
 		return False
 	#------------------------------------------------------------
 	def edit(vaccination=None):
@@ -935,8 +942,7 @@ class cVaccinationEAPnl(wxgVaccinationEAPnl.wxgVaccinationEAPnl, gmEditArea.cGen
 				workplace = gmSurgery.gmCurrentPractice().active_workplace,
 				bias = u'user'
 			)
-
-		webbrowser.open(url = url, new = False, autoraise = True)
+		gmNetworkTools.open_url_in_browser(url = url)
 	#----------------------------------------------------------------
 	def _on_add_vaccine_button_pressed(self, event):
 		edit_vaccine(parent = self, vaccine = None, single_entry = False)
